# Abstract data types

This is a package that adds some complex data structures like arrays and graphs that are tailored to suit our needs. Over time we added methods that helped us in specific situations such as the generation of a Voronoi diagram that is included in the matrix, which is perhaps not so related to its operation, however, we added them anyway because the objective to create this library was to learn more about python and try to make as many advances from scratch

## Authors

* **Arcos Juan** - [ArcosJuan](https://github.com/ArcosJuan).
* **Carazo Medley Matías** - [Matimed](https://github.com/Matimed).

## License

_abstract-data-types as a whole is licensed under the MIT License - Look the [LICENSE](LICENSE) file for details._


